==> xlniuxdata-vipgame-1.0.0-20141225.035105-5-sources.jar: com/xunlei/niux/data/vipgame/dto/tasks/TaskGameConfigDTO.java <==
package com.xunlei.niux.data.vipgame.dto.tasks;

import com.xunlei.niux.data.vipgame.vo.tasks.TaskDutyConfig;

import java.util.List;

/**
 * Created by jamesjxin on 14-6-12.
 */
public class TaskGameConfigDTO {
    private Long seqId;
    private String gameId;
    private String picUrl;
    private Integer showOrder;
    private Integer task1ref;
    private Integer task2ref;
    private Integer task3ref;
    private Integer task4ref;

    private TaskDutyConfig task1;
    private TaskDutyConfig task2;
    private TaskDutyConfig task3;
    private TaskDutyConfig task4;

    private List<TaskDutyConfig> taskConfigList;

    public Long getSeqId() {
        return seqId;
    }

    public void setSeqId(Long seqId) {
        this.seqId = seqId;
    }

    public String getGameId() {
        return gameId;
    }

    public void setGameId(String gameId) {
        this.gameId = gameId;
    }

    public String getPicUrl() {
        return picUrl;
    }

    public void setPicUrl(String picUrl) {
        this.picUrl = picUrl;
    }

    public Integer getShowOrder() {
        return showOrder;
    }

    public void setShowOrder(Integer showOrder) {
        this.showOrder = showOrder;
    }

    public Integer getTask1ref() {
        return task1ref;
    }

    public void setTask1ref(Integer task1ref) {
        this.task1ref = task1ref;
    }

    public Integer getTask2ref() {
        return task2ref;
    }

    public void setTask2ref(Integer task2ref) {
        this.task2ref = task2ref;
    }

    public Integer getTask3ref() {
        return task3ref;
    }

    public void setTask3ref(Integer task3ref) {
        this.task3ref = task3ref;
    }

    public Integer getTask4ref() {
        return task4ref;
    }

    public void setTask4ref(Integer task4ref) {
        this.task4ref = task4ref;
    }

    public TaskDutyConfig getTask1() {
        return task1;
    }

    public void setTask1(TaskDutyConfig task1) {
        this.task1 = task1;
    }

    public TaskDutyConfig getTask2() {
        return task2;
    }

    public void setTask2(TaskDutyConfig task2) {
        this.task2 = task2;
    }

    public TaskDutyConfig getTask3() {
        return task3;
    }

    public void setTask3(TaskDutyConfig task3) {
        this.task3 = task3;
    }

    public TaskDutyConfig getTask4() {
        return task4;
    }

    public void setTask4(TaskDutyConfig task4) {
        this.task4 = task4;
    }

    public List<TaskDutyConfig> getTaskConfigList() {
        return taskConfigList;
    }

    public void setTaskConfigList(List<TaskDutyConfig> taskConfigList) {
        this.taskConfigList = taskConfigList;
    }
}

==> xlniuxdata-vipgame-1.0.30-20150929.081848-31-sources.jar: com/xunlei/niux/data/vipgame/dto/tasks/TaskGameConfigDTO.java <==
package com.xunlei.niux.data.vipgame.dto.tasks;

import com.xunlei.niux.data.vipgame.vo.tasks.TaskDutyConfig;

import java.util.List;

/**
 * Created by jamesjxin on 14-6-12.
 */
public class TaskGameConfigDTO {
    private Long seqId;
    private String gameId;
    private String picUrl;
    private Integer showOrder;
    private Integer task1ref;
    private Integer task2ref;
    private Integer task3ref;
    private Integer task4ref;

    private TaskDutyConfig task1;
    private TaskDutyConfig task2;
    private TaskDutyConfig task3;
    private TaskDutyConfig task4;
    private Boolean isRecommend;

    private List<TaskDutyConfig> taskConfigList;

    public Long getSeqId() {
        return seqId;
    }

    public void setSeqId(Long seqId) {
        this.seqId = seqId;
    }

    public String getGameId() {
        return gameId;
    }

    public void setGameId(String gameId) {
        this.gameId = gameId;
    }

    public String getPicUrl() {
        return picUrl;
    }

    public void setPicUrl(String picUrl) {
        this.picUrl = picUrl;
    }

    public Integer getShowOrder() {
        return showOrder;
    }

    public void setShowOrder(Integer showOrder) {
        this.showOrder = showOrder;
    }

    public Integer getTask1ref() {
        return task1ref;
    }

    public void setTask1ref(Integer task1ref) {
        this.task1ref = task1ref;
    }

    public Integer getTask2ref() {
        return task2ref;
    }

    public void setTask2ref(Integer task2ref) {
        this.task2ref = task2ref;
    }

    public Integer getTask3ref() {
        return task3ref;
    }

    public void setTask3ref(Integer task3ref) {
        this.task3ref = task3ref;
    }

    public Integer getTask4ref() {
        return task4ref;
    }

    public void setTask4ref(Integer task4ref) {
        this.task4ref = task4ref;
    }

    public TaskDutyConfig getTask1() {
        return task1;
    }

    public void setTask1(TaskDutyConfig task1) {
        this.task1 = task1;
    }

    public TaskDutyConfig getTask2() {
        return task2;
    }

    public void setTask2(TaskDutyConfig task2) {
        this.task2 = task2;
    }

    public TaskDutyConfig getTask3() {
        return task3;
    }

    public void setTask3(TaskDutyConfig task3) {
        this.task3 = task3;
    }

    public TaskDutyConfig getTask4() {
        return task4;
    }

    public void setTask4(TaskDutyConfig task4) {
        this.task4 = task4;
    }

    public Boolean getIsRecommend() {
        return isRecommend;
    }

    public void setIsRecommend(Boolean isRecommend) {
        this.isRecommend = isRecommend;
    }

    public List<TaskDutyConfig> getTaskConfigList() {
        return taskConfigList;
    }

    public void setTaskConfigList(List<TaskDutyConfig> taskConfigList) {
        this.taskConfigList = taskConfigList;
    }
}
